@@ -15,7 +15,6 @@
  */
 package org.kie.wb.selenium.model.persps;
 
-import org.jboss.arquillian.graphene.findby.ByJQuery;
 import org.jboss.arquillian.graphene.page.Page;
 import org.kie.wb.selenium.util.BusyPopup;
 import org.kie.wb.selenium.util.Waits;
@@ -23,8 +22,7 @@ import org.openqa.selenium.By;
 
 public class ProcessDashboardPerspective extends AbstractPerspective {
 
-    private static final By PROCESS_REPORTS_BREADCRUMB =
-            ByJQuery.selector("[data-field='breadcrumb']:contains('Process Reports')");
+    private static final By PROCESS_REPORTS_BREADCRUMB = By.xpath("//a[contains(text(), 'Process Reports')]");
 
     @Page
     private BusyPopup loadingIndicator;
